Bibliography
============

.. [N82] Noblesse, **The Green function in the theory of radiation and diffraction of regular water waves by a body**, J. Engg. Math., 1982

.. [Del87] Delhommeau, **Problèmes de diffraction-radiation et de résistance des vagues : étude théorique et résolution numérique par la méthode des singularités**, PhD Thesis, École Nationale Supérieure de Mécanique de Nantes, 1987

.. [Del89] Delhommeau, **Amélioration des codes de calcul de diffraction-raditation au premier ordre**, 2émes Journées de l'Hydrodynamique, 1989

.. [Del93] Delhommeau, **The seakeeping codes Aquadyn and Aquaplus**, 19th WEGEMT School, Numerical Simulation of Hydrodynamics: Ships and Offshore Structures, 1993

.. [BD15] Babarit and Delhommeau, **Theoretical and numerical aspects of the open source BEM solver NEMOH**, Proceedings of the 11th European Wave and Tidal Energy Conference (EWTEC2015), Nantes, France, 2015.

.. .. [PKR17] Penalba Retes, Kelly and Ringwood, **Using NEMOH for modelling wave energy converters: A comparative study with WAMIT**, Proceedings of the 12th European Wave and Tidal Energy Conference (EWTEC2017), Cork, Ireland, 2017.

.. [AD18] Ancellin and Dias, **Using the floating body symmetries to speed up the numerical computation of hydrodynamics coefficients with Nemoh**, Proceedings of 37th International Conference on Ocean, Offshore and Arctic Engineering (OMAE2018), Madrid, Spain, 2018.

.. [X18] Xie et al., **Comparison of existing methods for the calculation of the infinite water depth free-surface Green function for the wave-structure interaction problem**, Applied Ocean Research 81 (2018) 150--163

.. .. [FK20] Falnes and Kurniawan, **Ocean waves and oscillating systems linear interactions including wave energy extraction**, Cambridge University Press, 2020.

.. [Liu19] Liu, **HAMS: A frequency-domain preprocessor for wave-structure interactions—Theory, development, and application**, Journal of Marine Science and Engineering, 7(3), 81.

.. [N20] Newman, **A simplified derivation of the ordinary differential equations for the free-surface Green functions**, Applied Ocean Research, 2020

.. [D22] Donatini et al., **Implementation of forward speed effects on an open source seakeeping solver**. In 6th MASHCON: International Conference on Ship Manoeuvring in Shallow and Confined Water, 2022
